--[[
    MyRolePlay 4 (C) 2010-2019 Etarna Moonshyne <etarna@moonshyne.org>, Katorie @ Moon Guard

    Licensed under GNU General Public Licence version 2 or, at your option, any later version

    UI_ChangeLog.lua - Display patch notes after an update.
]]

local changeLogText = {};

function mrp:FormatChangeLog()
    local changeLogConversionTable = {};
    local changeLogOutput = ""
    for i = 1, #changeLogText, 1 do
        changeLogConversionTable[i] = {};
        changeLogConversionTable[i]["version"] = "{h3:c}|cffFF7700v" .. changeLogText[i]["version"] .. "|r{/h3}\n"
        for l = 1, #changeLogText[i], 1 do
            changeLogConversionTable[i][l] = {}
            if(changeLogText[i][l]["title"] ~= "") then
                changeLogConversionTable[i][l]["title"] = "{h3}" .. changeLogText[i][l]["title"] .. "{/h3}\n"
            else
                changeLogConversionTable[i][l]["title"] = ""
            end
            if(changeLogText[i][l]["text"] ~= "") then
                changeLogConversionTable[i][l]["text"] = changeLogText[i][l]["text"] .. "\n\n"
            else
                changeLogConversionTable[i][l]["text"] = ""
            end
        end
    end
    for i = 1, #changeLogConversionTable, 1 do
        changeLogOutput = changeLogOutput .. changeLogConversionTable[i]["version"]
        for l = 1, #changeLogConversionTable[i], 1 do
            changeLogOutput = changeLogOutput .. changeLogConversionTable[i][l]["title"]
            changeLogOutput = changeLogOutput .. changeLogConversionTable[i][l]["text"]
        end
    end

    changeLogOutput = mrp:CreateURLLink(changeLogOutput);
    changeLogOutput = mrp:ConvertStringToHTML(changeLogOutput);
    MyRolePlayChangeLogHTMLFrame:SetText(changeLogOutput)
end


local f = CreateFrame("Frame", "MyRolePlayChangeLogFrame", UIParent, BackdropTemplateMixin and "BackdropTemplate");

-- Setup the frame.
f:SetToplevel(true);
f:SetFrameStrata("HIGH");
f:SetMovable(true);
f:EnableMouse(true);
f:Hide();
f:ClearAllPoints();
f:SetSize(600, 400);
f:SetPoint("CENTER", UIParent, "CENTER", 0, 0);


-- Set backdrop for the picker frame
f:SetBackdrop(
    {
        bgFile = "Interface/Tooltips/UI-Tooltip-Background",
        edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
        tile = true, tileSize = 16, edgeSize = 16,
        insets = {
            left = 4,
            right = 4,
            top = 4,
            bottom = 4
        }
    }
);
f:SetBackdropColor(0.0, 0.0, 0.0, 0.80);

-- Title text
f.title_label = f:CreateFontString();
f.title_label:ClearAllPoints();
f.title_label:SetSize(f:GetWidth(), 40);
f.title_label:SetPoint("TOPLEFT", f, "TOPLEFT", 0, -5);
f.title_label:SetFontObject(GameFontNormalHuge3);
f.title_label:SetText("|cff9955DDMyRolePlay Patch Notes|r");

f.sf = CreateFrame( "ScrollFrame", "MyRolePlayChangeLogScrollFrame", f, "UIPanelScrollFrameTemplate" )
f.sf:SetPoint( "TOPLEFT", f.title_label, "BOTTOMLEFT", 12, -5 )
f.sf:SetPoint( "BOTTOMRIGHT", f, "BOTTOMRIGHT", -28, 7 )

f.sf:EnableMouse(true)
f.sf.scrollbarHideable = false

ScrollBar_AdjustAnchors( MyRolePlayChangeLogScrollFrameScrollBar, -1, -1, 1)

f.sf.html = CreateFrame("SimpleHTML", "MyRolePlayChangeLogHTMLFrame", f.sf, BackdropTemplateMixin and "BackdropTemplate")
f.sf.html:SetSize(f.sf:GetWidth()-4, f.sf:GetHeight())
f.sf.html:SetFrameStrata("HIGH")
f.sf.html:SetBackdropColor(0, 0, 0, 1)
f.sf.html:SetFontObject( "GameFontHighlight" )
f.sf.html:SetFontObject("p", GameFontHighlight); -- GameFontNormal is gold.
f.sf.html:SetFontObject("h1", GameFontNormalHuge3);
f.sf.html:SetFontObject("h2", GameFontNormalHuge);
f.sf.html:SetFontObject("h3", GameFontNormalLarge);
f.sf.html:SetTextColor("h1", 1, 1, 1);
f.sf.html:SetTextColor("h2", 1, 1, 1);
--f.sf.html:SetTextColor("h3", 1, 1, 1);
f.sf.html:SetScript("OnHyperlinkClick", function(f, link, text, button, ...)
    if(link:match("mrpweblink")) then -- Creates a new hyperlink type to allow for clicking of web links.
        local linkName = link:match("^mrpweblink:(.+)");
        if(linkName) then
            mrp:ShowHyperlinkBox(linkName, linkName);
        end
        return;
    end
end)
f.sf.html:SetScript("OnHyperlinkEnter", function(f, link, text, button, ...)
    if(link:match("mrpweblink")) then
        local linkName = link:match("^mrpweblink:(.+)");
        if(linkName) then
            GameTooltip:SetOwner( f, "ANCHOR_CURSOR" )
            GameTooltip:SetText( text:match("%[.-%]"), 1.0, 1.0, 1.0 )
            GameTooltip:AddLine( linkName, 1.0, 0.8, 0.06)
            GameTooltip:Show()
        end
        return;
    end
end)
f.sf.html:SetScript( "OnHyperlinkLeave", GameTooltip_Hide )
f.sf.html:SetHyperlinksEnabled(1)

f.sf:SetScrollChild( f.sf.html )

f.sf.html:SetScript( "OnUpdate", function(self, elapsed)
    ScrollingEdit_OnUpdate(self, elapsed, self:GetParent())
end	)

ScrollFrame_OnScrollRangeChanged(MyRolePlayChangeLogScrollFrame)

-- Close button
f.close = CreateFrame("Button", nil, f, "UIPanelCloseButton")
f.close:SetPoint("TOPRIGHT", f, "TOPRIGHT", 0, 0)
f.close:SetScript("OnClick", function (self)
    MyRolePlayChangeLogFrame:Hide();
end )

changeLogText[1] = {
    ["version"] = "9.0.5.500 Burning Crusade Prepatch Update (18 May 2021)",
	[1] = {
        ["title"] = "One Version, Three Clients",
        ["text"] = table.concat({
			"- This version of MyRolePlay combines Retail, Burning Crusade, and Classic all into one compatible MRP version that works across all three clients. From a development standpoint, this makes updates easier as they only have to be applied to one version.",
			"- Specific features, icons, music, and images will still only be available on certain versions of the game. This is because, for example, icons created after Burning Crusade do not exist in the game files for that client.",
			"- The addon version number will still correspond to the latest retail patch, even though it will be receiving necessary updates for all 3 clients.",
        }, "\n\n"),
    },
	[2] = {
        ["title"] = "Bug Fixes / Improvements / BC Compatibility Changes",
        ["text"] = table.concat({
			"- Several bugs have been fixed related to the transition to Burning Crusade.",
			"- Icons and music from Burning Crusade are now available when using that version of the WoW client.",
			"- Corrected an issue involving ElvUI where the profile editor would be overlapped by a transparent background.",
			"- Please report bugs at https://www.curseforge.com/wow/addons/my-role-play/issues",
			"- The default header colours for Burning Crusade are themed green to match the expansion. You can change them in settings.",
		}, "\n\n"),
    },
};
